==> hibiscus.js-1.2.1.tgz: package/validators/validators.directive.js <==
import { Directive, Inject, Input, LOCALE_ID } from '@angular/core';
import { NG_VALIDATORS } from '@angular/forms';
import { includesValidator, equalToValidator, rangeLengthValidator, minValidator, maxValidator, rangeValidator, digitsValidator, numberValidator, urlValidator, emailValidator, dateValidator, dateISOValidator, jsonValidator, base64Validator, phoneValidator, uuidValidator, equalValidator, beforeDateValidator, afterDateValidator, requiredWithTrim } from './validators';
var RequiredWithTrimDirective = /** @class */ (function () {
    function RequiredWithTrimDirective() {
    }
    RequiredWithTrimDirective.prototype.validate = function (control) {
        return requiredWithTrim(control);
    };
    RequiredWithTrimDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiRequiredWithTrim]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: RequiredWithTrimDirective, multi: true }]
                },] },
    ];
    return RequiredWithTrimDirective;
}());
export { RequiredWithTrimDirective };
var RangeLengthDirective = /** @class */ (function () {
    function RangeLengthDirective() {
    }
    RangeLengthDirective.prototype.validate = function (control) {
        return rangeLengthValidator(this.hiRangeLength)(control);
    };
    RangeLengthDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiRangeLength]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: RangeLengthDirective, multi: true }]
                },] },
    ];
    /** @nocollapse */
    RangeLengthDirective.propDecorators = {
        "hiRangeLength": [{ type: Input },],
    };
    return RangeLengthDirective;
}());
export { RangeLengthDirective };
var MinDirective = /** @class */ (function () {
    function MinDirective() {
    }
    MinDirective.prototype.validate = function (control) {
        return minValidator(this.hiMin)(control);
    };
    MinDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiMin]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: MinDirective, multi: true }]
                },] },
    ];
    /** @nocollapse */
    MinDirective.propDecorators = {
        "hiMin": [{ type: Input },],
    };
    return MinDirective;
}());
export { MinDirective };
var MaxDirective = /** @class */ (function () {
    function MaxDirective() {
    }
    MaxDirective.prototype.validate = function (control) {
        return maxValidator(this.hiMax)(control);
    };
    MaxDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiMax]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: MaxDirective, multi: true }]
                },] },
    ];
    /** @nocollapse */
    MaxDirective.propDecorators = {
        "hiMax": [{ type: Input },],
    };
    return MaxDirective;
}());
export { MaxDirective };
var RangeDirective = /** @class */ (function () {
    function RangeDirective() {
    }
    RangeDirective.prototype.validate = function (control) {
        return rangeValidator(this.hiRange)(control);
    };
    RangeDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiRange]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: RangeDirective, multi: true }]
                },] },
    ];
    /** @nocollapse */
    RangeDirective.propDecorators = {
        "hiRange": [{ type: Input },],
    };
    return RangeDirective;
}());
export { RangeDirective };
var DigitsDirective = /** @class */ (function () {
    function DigitsDirective() {
    }
    DigitsDirective.prototype.validate = function (control) {
        return digitsValidator()(control);
    };
    DigitsDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiDigits]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: DigitsDirective, multi: true }]
                },] },
    ];
    return DigitsDirective;
}());
export { DigitsDirective };
var NumberDirective = /** @class */ (function () {
    function NumberDirective() {
    }
    NumberDirective.prototype.validate = function (control) {
        return numberValidator()(control);
    };
    NumberDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiNumber]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: NumberDirective, multi: true }]
                },] },
    ];
    return NumberDirective;
}());
export { NumberDirective };
var UrlDirective = /** @class */ (function () {
    function UrlDirective() {
    }
    UrlDirective.prototype.validate = function (control) {
        return urlValidator()(control);
    };
    UrlDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiUrl]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: UrlDirective, multi: true }]
                },] },
    ];
    return UrlDirective;
}());
export { UrlDirective };
var EmailDirective = /** @class */ (function () {
    function EmailDirective() {
    }
    EmailDirective.prototype.validate = function (control) {
        return emailValidator()(control);
    };
    EmailDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiEmail]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: EmailDirective, multi: true }]
                },] },
    ];
    return EmailDirective;
}());
export { EmailDirective };
var DateDirective = /** @class */ (function () {
    function DateDirective() {
    }
    DateDirective.prototype.validate = function (control) {
        return dateValidator()(control);
    };
    DateDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiDate]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: DateDirective, multi: true }]
                },] },
    ];
    return DateDirective;
}());
export { DateDirective };
var DateISODirective = /** @class */ (function () {
    function DateISODirective() {
    }
    DateISODirective.prototype.validate = function (control) {
        return dateISOValidator()(control);
    };
    DateISODirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiDateISO]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: DateISODirective, multi: true }]
                },] },
    ];
    return DateISODirective;
}());
export { DateISODirective };
var JsonDirective = /** @class */ (function () {
    function JsonDirective() {
    }
    JsonDirective.prototype.validate = function (control) {
        return jsonValidator()(control);
    };
    JsonDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiJson]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: JsonDirective, multi: true }]
                },] },
    ];
    return JsonDirective;
}());
export { JsonDirective };
var Base64Directive = /** @class */ (function () {
    function Base64Directive() {
    }
    Base64Directive.prototype.validate = function (control) {
        return base64Validator()(control);
    };
    Base64Directive.decorators = [
        { type: Directive, args: [{
                    selector: '[hiBase64]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: Base64Directive, multi: true }]
                },] },
    ];
    return Base64Directive;
}());
export { Base64Directive };
var PhoneDirective = /** @class */ (function () {
    function PhoneDirective(locale) {
        this.locale = locale;
    }
    PhoneDirective.prototype.validate = function (control) {
        return phoneValidator(this.hiPhone || this.locale)(control);
    };
    PhoneDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiPhone]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: PhoneDirective, multi: true }]
                },] },
    ];
    /** @nocollapse */
    PhoneDirective.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [LOCALE_ID,] },] },
    ]; };
    PhoneDirective.propDecorators = {
        "hiPhone": [{ type: Input },],
    };
    return PhoneDirective;
}());
export { PhoneDirective };
var UUIDDirective = /** @class */ (function () {
    function UUIDDirective() {
    }
    UUIDDirective.prototype.validate = function (control) {
        return uuidValidator()(control);
    };
    UUIDDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiUUID]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: UUIDDirective, multi: true }]
                },] },
    ];
    return UUIDDirective;
}());
export { UUIDDirective };
var EqualDirective = /** @class */ (function () {
    function EqualDirective() {
    }
    EqualDirective.prototype.validate = function (control) {
        return equalValidator(this.hiEqual)(control);
    };
    EqualDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiEqual]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: EqualDirective, multi: true }]
                },] },
    ];
    /** @nocollapse */
    EqualDirective.propDecorators = {
        "hiEqual": [{ type: Input },],
    };
    return EqualDirective;
}());
export { EqualDirective };
var IncludesDirective = /** @class */ (function () {
    function IncludesDirective() {
    }
    IncludesDirective.prototype.validate = function (control) {
        return includesValidator(this.hiIncludes)(control);
    };
    IncludesDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiIncludes]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: IncludesDirective, multi: true }]
                },] },
    ];
    /** @nocollapse */
    IncludesDirective.propDecorators = {
        "hiIncludes": [{ type: Input },],
    };
    return IncludesDirective;
}());
export { IncludesDirective };
var EqualToDirective = /** @class */ (function () {
    function EqualToDirective() {
    }
    Object.defineProperty(EqualToDirective.prototype, "hiEqualTo", {
        set: function (target) {
            this.validatorFn = equalToValidator(target);
        },
        enumerable: true,
        configurable: true
    });
    EqualToDirective.prototype.validate = function (control) {
        return this.validatorFn(control);
    };
    EqualToDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiEqualTo]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: EqualToDirective, multi: true }]
                },] },
    ];
    /** @nocollapse */
    EqualToDirective.propDecorators = {
        "hiEqualTo": [{ type: Input },],
    };
    return EqualToDirective;
}());
export { EqualToDirective };
var BeforeDateDirective = /** @class */ (function () {
    function BeforeDateDirective() {
    }
    Object.defineProperty(BeforeDateDirective.prototype, "hiBeforeDate", {
        set: function (target) {
            this.validatorFn = beforeDateValidator(target);
        },
        enumerable: true,
        configurable: true
    });
    BeforeDateDirective.prototype.validate = function (control) {
        return this.validatorFn(control);
    };
    BeforeDateDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiBeforeDate]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: BeforeDateDirective, multi: true }]
                },] },
    ];
    /** @nocollapse */
    BeforeDateDirective.propDecorators = {
        "hiBeforeDate": [{ type: Input },],
    };
    return BeforeDateDirective;
}());
export { BeforeDateDirective };
var AfterDateDirective = /** @class */ (function () {
    function AfterDateDirective() {
    }
    Object.defineProperty(AfterDateDirective.prototype, "hiAfterDate", {
        set: function (target) {
            this.validatorFn = afterDateValidator(target);
        },
        enumerable: true,
        configurable: true
    });
    AfterDateDirective.prototype.validate = function (control) {
        return this.validatorFn(control);
    };
    AfterDateDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiAfterDate]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: AfterDateDirective, multi: true }]
                },] },
    ];
    /** @nocollapse */
    AfterDateDirective.propDecorators = {
        "hiAfterDate": [{ type: Input },],
    };
    return AfterDateDirective;
}());
export { AfterDateDirective };

==> hibiscus.js-1.2.3.tgz: package/validators/validators.directive.js <==
import { Directive, Inject, Input, LOCALE_ID } from '@angular/core';
import { NG_VALIDATORS } from '@angular/forms';
import { includesValidator, equalToValidator, rangeLengthValidator, minValidator, maxValidator, rangeValidator, digitsValidator, numberValidator, urlValidator, emailValidator, dateValidator, dateISOValidator, jsonValidator, base64Validator, phoneValidator, uuidValidator, equalValidator, beforeDateValidator, afterDateValidator, requiredWithTrim } from './validators';
var RequiredWithTrimDirective = (function () {
    function RequiredWithTrimDirective() {
    }
    RequiredWithTrimDirective.prototype.validate = function (control) {
        return requiredWithTrim(control);
    };
    RequiredWithTrimDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiRequiredWithTrim]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: RequiredWithTrimDirective, multi: true }]
                },] },
    ];
    return RequiredWithTrimDirective;
}());
export { RequiredWithTrimDirective };
var RangeLengthDirective = (function () {
    function RangeLengthDirective() {
    }
    RangeLengthDirective.prototype.validate = function (control) {
        return rangeLengthValidator(this.hiRangeLength)(control);
    };
    RangeLengthDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiRangeLength]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: RangeLengthDirective, multi: true }]
                },] },
    ];
    RangeLengthDirective.propDecorators = {
        "hiRangeLength": [{ type: Input },],
    };
    return RangeLengthDirective;
}());
export { RangeLengthDirective };
var MinDirective = (function () {
    function MinDirective() {
    }
    MinDirective.prototype.validate = function (control) {
        return minValidator(this.hiMin)(control);
    };
    MinDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiMin]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: MinDirective, multi: true }]
                },] },
    ];
    MinDirective.propDecorators = {
        "hiMin": [{ type: Input },],
    };
    return MinDirective;
}());
export { MinDirective };
var MaxDirective = (function () {
    function MaxDirective() {
    }
    MaxDirective.prototype.validate = function (control) {
        return maxValidator(this.hiMax)(control);
    };
    MaxDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiMax]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: MaxDirective, multi: true }]
                },] },
    ];
    MaxDirective.propDecorators = {
        "hiMax": [{ type: Input },],
    };
    return MaxDirective;
}());
export { MaxDirective };
var RangeDirective = (function () {
    function RangeDirective() {
    }
    RangeDirective.prototype.validate = function (control) {
        return rangeValidator(this.hiRange)(control);
    };
    RangeDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiRange]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: RangeDirective, multi: true }]
                },] },
    ];
    RangeDirective.propDecorators = {
        "hiRange": [{ type: Input },],
    };
    return RangeDirective;
}());
export { RangeDirective };
var DigitsDirective = (function () {
    function DigitsDirective() {
    }
    DigitsDirective.prototype.validate = function (control) {
        return digitsValidator()(control);
    };
    DigitsDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiDigits]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: DigitsDirective, multi: true }]
                },] },
    ];
    return DigitsDirective;
}());
export { DigitsDirective };
var NumberDirective = (function () {
    function NumberDirective() {
    }
    NumberDirective.prototype.validate = function (control) {
        return numberValidator()(control);
    };
    NumberDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiNumber]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: NumberDirective, multi: true }]
                },] },
    ];
    return NumberDirective;
}());
export { NumberDirective };
var UrlDirective = (function () {
    function UrlDirective() {
    }
    UrlDirective.prototype.validate = function (control) {
        return urlValidator()(control);
    };
    UrlDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiUrl]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: UrlDirective, multi: true }]
                },] },
    ];
    return UrlDirective;
}());
export { UrlDirective };
var EmailDirective = (function () {
    function EmailDirective() {
    }
    EmailDirective.prototype.validate = function (control) {
        return emailValidator()(control);
    };
    EmailDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiEmail]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: EmailDirective, multi: true }]
                },] },
    ];
    return EmailDirective;
}());
export { EmailDirective };
var DateDirective = (function () {
    function DateDirective() {
    }
    DateDirective.prototype.validate = function (control) {
        return dateValidator()(control);
    };
    DateDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiDate]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: DateDirective, multi: true }]
                },] },
    ];
    return DateDirective;
}());
export { DateDirective };
var DateISODirective = (function () {
    function DateISODirective() {
    }
    DateISODirective.prototype.validate = function (control) {
        return dateISOValidator()(control);
    };
    DateISODirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiDateISO]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: DateISODirective, multi: true }]
                },] },
    ];
    return DateISODirective;
}());
export { DateISODirective };
var JsonDirective = (function () {
    function JsonDirective() {
    }
    JsonDirective.prototype.validate = function (control) {
        return jsonValidator()(control);
    };
    JsonDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiJson]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: JsonDirective, multi: true }]
                },] },
    ];
    return JsonDirective;
}());
export { JsonDirective };
var Base64Directive = (function () {
    function Base64Directive() {
    }
    Base64Directive.prototype.validate = function (control) {
        return base64Validator()(control);
    };
    Base64Directive.decorators = [
        { type: Directive, args: [{
                    selector: '[hiBase64]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: Base64Directive, multi: true }]
                },] },
    ];
    return Base64Directive;
}());
export { Base64Directive };
var PhoneDirective = (function () {
    function PhoneDirective(locale) {
        this.locale = locale;
    }
    PhoneDirective.prototype.validate = function (control) {
        return phoneValidator(this.hiPhone || this.locale)(control);
    };
    PhoneDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiPhone]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: PhoneDirective, multi: true }]
                },] },
    ];
    PhoneDirective.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [LOCALE_ID,] },] },
    ]; };
    PhoneDirective.propDecorators = {
        "hiPhone": [{ type: Input },],
    };
    return PhoneDirective;
}());
export { PhoneDirective };
var UUIDDirective = (function () {
    function UUIDDirective() {
    }
    UUIDDirective.prototype.validate = function (control) {
        return uuidValidator()(control);
    };
    UUIDDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiUUID]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: UUIDDirective, multi: true }]
                },] },
    ];
    return UUIDDirective;
}());
export { UUIDDirective };
var EqualDirective = (function () {
    function EqualDirective() {
    }
    EqualDirective.prototype.validate = function (control) {
        return equalValidator(this.hiEqual)(control);
    };
    EqualDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiEqual]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: EqualDirective, multi: true }]
                },] },
    ];
    EqualDirective.propDecorators = {
        "hiEqual": [{ type: Input },],
    };
    return EqualDirective;
}());
export { EqualDirective };
var IncludesDirective = (function () {
    function IncludesDirective() {
    }
    IncludesDirective.prototype.validate = function (control) {
        return includesValidator(this.hiIncludes)(control);
    };
    IncludesDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiIncludes]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: IncludesDirective, multi: true }]
                },] },
    ];
    IncludesDirective.propDecorators = {
        "hiIncludes": [{ type: Input },],
    };
    return IncludesDirective;
}());
export { IncludesDirective };
var EqualToDirective = (function () {
    function EqualToDirective() {
    }
    Object.defineProperty(EqualToDirective.prototype, "hiEqualTo", {
        set: function (target) {
            this.validatorFn = equalToValidator(target);
        },
        enumerable: true,
        configurable: true
    });
    EqualToDirective.prototype.validate = function (control) {
        return this.validatorFn(control);
    };
    EqualToDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiEqualTo]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: EqualToDirective, multi: true }]
                },] },
    ];
    EqualToDirective.propDecorators = {
        "hiEqualTo": [{ type: Input },],
    };
    return EqualToDirective;
}());
export { EqualToDirective };
var BeforeDateDirective = (function () {
    function BeforeDateDirective() {
    }
    Object.defineProperty(BeforeDateDirective.prototype, "hiBeforeDate", {
        set: function (target) {
            this.validatorFn = beforeDateValidator(target);
        },
        enumerable: true,
        configurable: true
    });
    BeforeDateDirective.prototype.validate = function (control) {
        return this.validatorFn(control);
    };
    BeforeDateDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiBeforeDate]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: BeforeDateDirective, multi: true }]
                },] },
    ];
    BeforeDateDirective.propDecorators = {
        "hiBeforeDate": [{ type: Input },],
    };
    return BeforeDateDirective;
}());
export { BeforeDateDirective };
var AfterDateDirective = (function () {
    function AfterDateDirective() {
    }
    Object.defineProperty(AfterDateDirective.prototype, "hiAfterDate", {
        set: function (target) {
            this.validatorFn = afterDateValidator(target);
        },
        enumerable: true,
        configurable: true
    });
    AfterDateDirective.prototype.validate = function (control) {
        return this.validatorFn(control);
    };
    AfterDateDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[hiAfterDate]',
                    providers: [{ provide: NG_VALIDATORS, useExisting: AfterDateDirective, multi: true }]
                },] },
    ];
    AfterDateDirective.propDecorators = {
        "hiAfterDate": [{ type: Input },],
    };
    return AfterDateDirective;
}());
export { AfterDateDirective };
